@@ -11,14 +11,14 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::JQUELIN;
-our $VERSION = '1.100130';
+our $VERSION = '1.100220';
 # ABSTRACT: build & release a distribution like jquelin
 
 use Dist::Zilla::Plugin::AllFiles;
 use Dist::Zilla::Plugin::AutoPrereq;
 use Dist::Zilla::Plugin::AutoVersion;
 use Dist::Zilla::Plugin::CheckChangeLog;
-use Dist::Zilla::Plugin::CompileTests;
+use Dist::Zilla::Plugin::CompileTests 1.100220;
 use Dist::Zilla::Plugin::CriticTests;
 use Dist::Zilla::Plugin::ExtraTests;
 use Dist::Zilla::Plugin::InstallDirs;
@@ -61,6 +61,11 @@ sub bundle_config {
         ? { skip => $arg->{skip_prereq} }
         : {};
 
+    # params for compiletests
+    my $compile_params = defined $arg->{fake_home}
+        ? { fake_home => $arg->{fake_home} }
+        : {};
+
     # params for pod weaver
     $arg->{weaver} ||= 'pod';
 
@@ -76,7 +81,7 @@ sub bundle_config {
 
         # -- fetch & generate files
         [ AllFiles     => {} ],
-        [ CompileTests => {} ],
+        [ CompileTests => $compile_params ],
         [ CriticTests  => {} ],
         [ MetaTests    => {} ],
         [ PodTests     => {} ],
@@ -145,12 +150,16 @@ Dist::Zilla::PluginBundle::JQUELIN - build & release a distribution like jquelin
 
 =head1 VERSION
 
-version 1.100130
+version 1.100220
+
+=for Pod::Coverage::TrustPod bundle_config
 
 =head1 SYNOPSIS
 
+
 In your F<dist.ini>:
 
+
     [@JQUELIN]
     major_version = 1          ; this is the default
     weaver        = pod        ; default, can also be 'task'
@@ -158,9 +167,11 @@ In your F<dist.ini>:
 
 =head1 DESCRIPTION
 
+
 This is a plugin bundle to load all plugins that I am using. It is
 equivalent to:
 
+
     [AutoVersion]
 
     ; -- fetch & generate files
@@ -202,54 +213,78 @@ equivalent to:
 
 The following options are accepted:
 
+
 =over 4
 
+
 =item * C<major_version> - passed as C<major> option to the
 L<AutoVersion|Dist::Zilla::Plugin::AutoVersion> plugin. Default to 1.
 
+
 =item * C<weaver> - can be either C<pod> (default) or C<task>, to load
 respectively either L<PodWeaver|Dist::Zilla::Plugin::PodWeaver> or
 L<TaskWeaver|Dist::Zilla::Plugin::TaskWeaver>.
 
+
 =item * C<skip_prereq> - passed as C<skip> option to the
 L<AutoPrereq|Dist::Zilla::Plugin::AutoPrereq> plugin if set. No default.
 
-=back
 
-=for Pod::Coverage::TrustPod bundle_config
+=item * C<fake_home> - passed to
+L<CompileTests|Dist::Zilla::Plugin::CompileTests> to control whether
+to fake home.
+
+
+=back
 
 =head1 SEE ALSO
 
+
 You can look for information on this module at:
 
+
 =over 4
 
+
 =item * Search CPAN
 
+
 L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-JQUELIN>
 
+
 =item * See open / report bugs
 
+
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-PluginBundle-JQUELIN>
 
+
 =item * Mailing-list (same as dist-zilla)
 
+
 L<http://www.listbox.com/subscribe/?list_id=139292>
 
+
 =item * Git repository
 
+
 L<http://github.com/jquelin/dist-zilla-pluginbundle-jquelin>
 
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
+
 L<http://annocpan.org/dist/Dist-Zilla-PluginBundle-JQUELIN>
 
+
 =item * CPAN Ratings
 
+
 L<http://cpanratings.perl.org/d/Dist-Zilla-PluginBundle-JQUELIN>
 
+
 =back
 
+
 See also: L<Dist::Zilla::PluginBundle>.
 
 =head1 AUTHOR
